==> multi_crop-1.1.0.tar.gz: multi_crop/README.md <==
# How to use

## Global Preparation

Choose the crop plugin you want to use (focalPoint or ImageWidgetCrop) and configure it

### Focal point 

See Module README (https://www.drupal.org/project/focal_point)

- Install the module as usual. 
- Create a crop type (automatically created by focal_point activation )
- Create an image style for focal_point crop
  - use "focal point crop" or "focal point crop and scale" effect
- On the media
  - Go to the view mode, and on the image field, choose the image style configured before

### Image widget crop

See Module README (https://www.drupal.org/project/image_widget_crop)

- Install the module as usual. 
- Create a crop type with the constraint you want
- Create an image style for focal_point crop
  - use "manual crop" effect and choose the crop type created before
- On the media
  - Go to the view mode, and on the image field, choose the image style configured before

## Media Embed Contextual Cropping

The goal here are to add the capability to add a contextual crop on a media embed in a wysiwyg.

### Finishing Preparation 

- Activate multi_crop_embed and the plugin module adapted to the crop plugin : 
  - multi_crop_focal_point if you use focal point crop  
  - multi_crop_image_widget_crop if you use image_widget_crop 
- Edit the text format you want use (/admin/config/content/formats)
  - In the tool bar configuration, add the "insert from Media Library" plugin
  ![](documentation/assets/embed/toolbar.png)
  - In filters, activate "Embed media with Contextual Crop" (not the nativ "Embed media")
  ![](documentation/assets/embed/Filters.png)
  - In Filter settings, configure Embed Media with contextual with :
    - as "Default view mode", the view mode which use the crop plugin
    - as Media types selectable : at least the media type with the crop
  - ![](documentation/assets/embed/Filter_settings.png)
  - Save ! 
  
### Enjoy

In a content, you can add a media in the wysiwyg, you can edit it and crop it like you want
  ![](documentation/assets/embed/dialog.png)

## Media Reference Contextual Cropping

The goal here are to add the capabilities to contextualize a crop a on media reference.

### Finishing Preparation 

- Activate multi_crop_field_formatter and the plugin module adapted to the crop plugin : 
  - multi_crop_focal_point if you use focal point crop  
  - multi_crop_image_widget_crop if you use image_widget_crop 
- In your entity bundle (content type for example)
  - Add a "Reference / media with contextual modifications" instead of a basic " Reference / media" and configure it as usual media reference
  ![](documentation/assets/field/node_field.png)
- In your media entity view mode configuration
  - Replace native "image" field formatter by the "Multi Crop Image" and use the "image style" configured with the crop
    ![](documentation/assets/field/media_view_mode.png)
- In your media entity form mode configuration
  - Replace native "image" field widget by the Crop plugin dedicated widget : "Image (Focal Point)" or "ImageWidget Crop"   
  
### Enjoy

In a content, you can add a media in the referenced field and edit it localy.
![](documentation/assets/field/field_contextual.png)

You can have a media_reference with many time the same media but with different crops : 
![](documentation/assets/field/effect.png)

==> multi_crop-1.1.1.tar.gz: multi_crop/README.md <==
# How to use

## Global Preparation

Choose the crop plugin you want to use (focalPoint or ImageWidgetCrop) and configure it

### Focal point 

See Module README (https://www.drupal.org/project/focal_point)

- Install the module as usual. 
- Create a crop type (automatically created by focal_point activation )
- Create an image style for focal_point crop
  - use "focal point crop" or "focal point crop and scale" effect
- On the media
  - Go to the view mode, and on the image field, choose the image style configured before

### Image widget crop

See Module README (https://www.drupal.org/project/image_widget_crop)

- Install the module as usual. 
- Create a crop type with the constraint you want
- Create an image style for focal_point crop
  - use "manual crop" effect and choose the crop type created before
- On the media
  - Go to the view mode, and on the image field, choose the image style configured before

## Media Embed Contextual Cropping

The goal here are to add the capability to add a contextual crop on a media embed in a wysiwyg.

### Finishing Preparation 

- Activate multi_crop_embed and the plugin module adapted to the crop plugin : 
  - multi_crop_focal_point if you use focal point crop  
  - multi_crop_image_widget_crop if you use image_widget_crop 
- Edit the text format you want use (/admin/config/content/formats)
  - In the tool bar configuration, add the "insert from Media Library" plugin
  ![](documentation/assets/embed/toolbar.png)
  - In filters, activate "Embed media with Contextual Crop" (not the nativ "Embed media")
  ![](documentation/assets/embed/Filters.png)
  - In Filter settings, 
    - In Limit allowed HTML tags :
      - **Add "data-crop-settings" and "data-crop-type" attributs to the "drupal-media" HTML tag**
    - configure Embed Media with contextual with :
      - as "Default view mode", the view mode which use the crop plugin
      - as Media types selectable : at least the media type with the crop
  - ![](documentation/assets/embed/Filter_settings.png)
  - Save ! 
  
### Enjoy

In a content, you can add a media in the wysiwyg, you can edit it and crop it like you want
  ![](documentation/assets/embed/dialog.png)

## Media Reference Contextual Cropping

The goal here are to add the capabilities to contextualize a crop a on media reference.

### Finishing Preparation 

- Activate multi_crop_field_formatter and the plugin module adapted to the crop plugin : 
  - multi_crop_focal_point if you use focal point crop  
  - multi_crop_image_widget_crop if you use image_widget_crop 
- In your entity bundle (content type for example)
  - Add a "Reference / media with contextual modifications" instead of a basic " Reference / media" and configure it as usual media reference
  ![](documentation/assets/field/node_field.png)
- In your media entity view mode configuration
  - Replace native "image" field formatter by the "Multi Crop Image" and use the "image style" configured with the crop
    ![](documentation/assets/field/media_view_mode.png)
- In your media entity form mode configuration
  - Replace native "image" field widget by the Crop plugin dedicated widget : "Image (Focal Point)" or "ImageWidget Crop"   
  
### Enjoy

In a content, you can add a media in the referenced field and edit it localy.
![](documentation/assets/field/field_contextual.png)

You can have a media_reference with many time the same media but with different crops : 
![](documentation/assets/field/effect.png)
